@@ -4,7 +4,7 @@ msdoc - Greple module for access MS office docx/pptx/xlsx documents
 
 =head1 VERSION
 
-Version 1.00
+Version 1.01
 
 =head1 SYNOPSIS
 
@@ -53,6 +53,10 @@ Set indentation string.  Default is C<| >.
 
 =back
 
+=head1 INSTALL
+
+cpanm App::Greple::msdoc
+
 =head1 LICENSE
 
 Copyright (C) Kazumasa Utashiro.
@@ -72,7 +76,7 @@ Kazumasa Utashiro
 
 package App::Greple::msdoc;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 use strict;
 use warnings;
@@ -199,6 +203,30 @@ sub extract {
     $pid;
 }
 
+##
+## This is better implementation using in-memory file.
+## Works fine for first file, but does not work for the rest.
+## Hope to be solved.
+##
+sub __extract {
+    my %arg = @_;
+    my $stdin = do { local $/; <STDIN> };
+    my $format = $arg{format} // $default_format;
+    my $sub = do {
+	if    ($format eq 'text')         { \&extract_text }
+	elsif ($format eq 'indent-xml')   { \&indent_xml   }
+	elsif ($format eq 'separate-xml') { \&separate_xml }
+	else  { undef }
+    };
+    if ($sub) {
+	my @arg = $arg{&FILELABEL} ? (&FILELABEL => $arg{&FILELABEL}) : ();
+	for ($stdin) { $sub->(@arg) }
+    }
+
+    close STDIN;
+    open STDIN, "<", \$stdin || die "open: $!";
+}
+
 1;
 
 __DATA__
@@ -236,6 +264,6 @@ builtin indent-mark=s $indent_mark
 ##
 ## --dump
 ##
-option --dump --le &sub{} --need 0 --all
+option --dump --le &sub{} --need 0 --all --epilogue 'sub{exit(0)}'
 
 #  LocalWords:  msdoc Greple greple Mmsdoc docx ppt xml pptx xlsx xl
